@@ -1,4 +1,4 @@
-# Copyright (C) 2012,2013 The ESPResSo project
+# Copyright (C) 2012,2013,2014 The ESPResSo project
 #  
 # This file is part of ESPResSo.
 #  
@@ -33,7 +33,7 @@ proc dielectric_wall { args } {
   set sigma 0
   set type 0 
   set eps 0.
-  for { set argno 0 } { $argno < [ llength $args ] } { incr argo } {
+  for { set argno 0 } { $argno < [ llength $args ] } {  } {
     if { [ lindex $args $argno ] == "dist" } {
       incr argno
       set dist [ expr 1.0 * [ lindex $args $argno ] ]
@@ -157,7 +157,7 @@ proc dielectric_sphere { args } {
   set res 0
   set sigma 0
   set type 0 
-  for { set argno 0 } { $argno < [ llength $args ] } { incr argo } {
+  for { set argno 0 } { $argno < [ llength $args ] } { } {
     if { [ lindex $args $argno ] == "radius" } {
       incr argno
       set radius [ expr 1.* [ lindex $args $argno ] ]
@@ -216,7 +216,9 @@ proc dielectric_sphere { args } {
   for { set i 0 } { $i <= $n_half_equator } { incr i } {
     set phi 0.
     set n_circle [ expr 2*round($n_half_equator*sin($theta)) ]
-    set incr_phi [expr 2*$pi/$n_circle]
+    if {$n_circle > 0} {
+       set incr_phi [expr 2*$pi/$n_circle]                                      
+    }
     for { set j 0 } { $j < $n_circle } { incr j} {
        set x [ expr  $radius*cos($phi)*sin($theta) ]
        set y [ expr  $radius*sin($phi)*sin($theta) ]
@@ -264,7 +266,7 @@ proc dielectric_cylinder { args } {
   set direction 1
   set sigma 0
   set type 0
-  for { set argno 0 } { $argno < [ llength $args ] } { incr argo } {
+  for { set argno 0 } { $argno < [ llength $args ] } { } {
     if { [ lindex $args $argno ] == "center" } {
       incr argno
       set center_x [ lindex $args $argno ] 
@@ -351,6 +353,10 @@ proc dielectric_cylinder { args } {
   set incr_length_x [ expr $axis_x * $length / $n_length]
   set incr_length_y [ expr $axis_y * $length / $n_length]
   set incr_length_z [ expr $axis_z * $length / $n_length]
+  
+  if { !$covers } { 
+    set n_length [ expr $n_length - 1 ]
+  }
   set start_x [ expr $center_x - $axis_x * $length/2. ]
   set start_y [ expr $center_y - $axis_y * $length/2. ]
   set start_z [ expr $center_z - $axis_z * $length/2. ]
@@ -481,6 +487,10 @@ proc sign x {
 }
 
 
+proc sqrt { a } {
+  return [ expr sqrt($a+1e-8) ]
+}
+
 proc dielectric_pore { args } { 
   global n_induced_charges icc_areas icc_normals icc_epsilons icc_sigmas
   if { ![ info exists n_induced_charges ] } {
@@ -503,7 +513,7 @@ proc dielectric_pore { args } {
   set box_l_z [ lindex [ setmd box_l ] 2 ]
   set max_radius [ expr sqrt($box_l_x*$box_l_x+ $box_l_y*$box_l_y + $box_l_z*$box_l_z) ]
 
-  for { set argno 0 } { $argno < [ llength $args ] } { incr argo } {
+  for { set argno 0 } { $argno < [ llength $args ] } { } {
     if { [ lindex $args $argno ] == "center" } {
       incr argno
       set center_x [ expr 1.0*[ lindex $args $argno ] ]
@@ -569,6 +579,12 @@ proc dielectric_pore { args } {
       incr argno
       continue
     }
+    if { [ lindex $args $argno ] == "sigma" } {
+      incr argno
+      set sigma [ expr 1.0*[ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
     error "did not understand arg [ lindex args $argno ]"
   }
   set pi 3.1415
@@ -627,8 +643,8 @@ proc dielectric_pore { args } {
   set c1_r [ expr $r1 + $smoothing_radius ]
   set c2_r [ expr $r2 + $smoothing_radius ]
   set slope [ expr ($c2_r-$c1_r)/($c2_z-$c1_z) ]
-  set sina [ expr ($r2-$r1)/sqrt( pow(2*($length - $smoothing_radius),2) + pow($r1-$r2,2)) ]
-  set cosa [ expr sqrt(1-$sina*$sina) ]
+  set sina [ expr ($r2-$r1)/[ sqrt [ expr  pow(2*($length - $smoothing_radius),2) + pow($r1-$r2,2)] ] ]
+  set cosa [ sqrt [ expr (1-$sina*$sina) ] ]
   
 #  set z_left  [ expr $c1_z + [ sign $slope ] * sqrt($slope*$slope/(1+$slope*$slope))*$smoothing_radius]
 #  set z_right [ expr $c2_z + [ sign $slope ] * sqrt($slope*$slope/(1+$slope*$slope))*$smoothing_radius]
@@ -641,19 +657,19 @@ proc dielectric_pore { args } {
   set z [ expr - $length ]
   while { $z < $length } {
     if { $z < $z_left } {
-      set radius [ expr $c1_r - sqrt(  $smoothing_radius*$smoothing_radius - ($z-$c1_z)*($z-$c1_z) ) ] 
+      set radius [ expr $c1_r - [ sqrt [ expr  $smoothing_radius*$smoothing_radius - ($z-$c1_z)*($z-$c1_z) ] ] ] 
       set delta_b [ expr 2*$pi*$res/2/$pi/$smoothing_radius ]
       set sinb [ expr ($z - $c1_z)/$smoothing_radius ]
-      set sinbnew [ expr $sinb*cos($delta_b) + sqrt(1-$sinb*$sinb)*sin($delta_b) ]
+      set sinbnew [ expr $sinb*cos($delta_b) + [ sqrt [ expr 1-$sinb*$sinb ] ]*sin($delta_b) ]
       set incr_z [ expr $c1_z + $smoothing_radius * $sinbnew - $z ]
-      set slope_norm [ expr tan(asin($sinb)) ]
+      set slope_norm [ expr tan(asin($sinb+1e-8)) ]
     } elseif  { $z > $z_right } {
-      set radius [ expr $c2_r - sqrt(  $smoothing_radius*$smoothing_radius - ($z-$c2_z)*($z-$c2_z) ) ] 
+      set radius [ expr $c2_r - [ sqrt [ expr $smoothing_radius*$smoothing_radius - ($z-$c2_z)*($z-$c2_z) ] ] ] 
       set delta_b [ expr 2*$pi*$res/2/$pi/$smoothing_radius ]
       set sinb [ expr ($z - $c2_z)/$smoothing_radius ]
-      set sinbnew [ expr $sinb*cos($delta_b) + sqrt(1-$sinb*$sinb)*sin($delta_b) ]
+      set sinbnew [ expr $sinb*cos($delta_b) + [ sqrt [ expr 1-$sinb*$sinb ] ]*sin($delta_b) ]
       set incr_z [ expr $c2_z + $smoothing_radius * $sinbnew - $z ]
-      set slope_norm [ expr tan(asin($sinb)) ]
+      set slope_norm [ expr tan(asin($sinb+1e-8)) ]
       if { $incr_z <= 0 } { 
         set z 1000
         continue
@@ -738,7 +754,192 @@ proc dielectric_pore { args } {
     lappend icc_epsilons $eps
     lappend icc_sigmas $sigma 
   }
+}
 
+proc doit { x z nx nz } {
+  set p_no [ setmd n_part ]
+  upvar res res
+  upvar eps eps
+  upvar sigma sigma
+  upvar type type
+  global n_induced_charges icc_areas icc_normals icc_epsilons icc_sigmas
+  if { ![ info exists n_induced_charges ] } {
+    set n_induced_charges 0 
+    set icc_areas [ list ]
+    set icc_normals [ list ] 
+    set icc_epsilons [ list ] 
+    set icc_sigmas [ list ]
+  }
+  set ly [ lindex [ setmd box_l ] 1 ]
+  set ny [ expr int(floor($ly/$res)) ]
+  set ry [ expr $ly/$ny ]
+  
+  for { set i 0 } { $i < $ny } { incr i } {
+    part $p_no pos $x [ expr $i * $ry ] $z fix 1 1 1 type $type q [ expr $sigma*$res*$res +0.1*([ t_random ]-0.5) ]
+    incr n_induced_charges
+    incr p_no
+
+    lappend icc_normals [ list $nx 0 $nz ]
+
+    lappend icc_areas [ expr $res*$res ]
+    lappend icc_epsilons $eps
+    lappend icc_sigmas $sigma 
+  }
+}
+
+
+proc dielectric_slitpore { args } {
+  global n_induced_charges icc_areas icc_normals icc_epsilons icc_sigmas
+  if { ![ info exists n_induced_charges ] } {
+    set n_induced_charges 0 
+    set icc_areas [ list ]
+    set icc_normals [ list ] 
+    set icc_epsilons [ list ] 
+    set icc_sigmas [ list ]
+  }
+
+  set type 0
+  set eps 1.
+  set sigma 0.
+
+
+  for { set argno 0 } { $argno < [ llength $args ] } {  } {
+    if { [ lindex $args $argno ] == "pore_mouth" } {
+      incr argno
+      set pore_mouth [ expr 1.0 * [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "channel_width" } {
+      incr argno
+      set channel_width [ expr 1.0 * [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "pore_length" } {
+      incr argno
+      set pore_length [ expr 1.0 * [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "pore_width" } {
+      incr argno
+      set pore_width [ expr 1.0 * [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "upper_smoothing_radius" } {
+      incr argno
+      set upper_smoothing_radius [ expr 1.0 * [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "lower_smoothing_radius" } {
+      incr argno
+      set lower_smoothing_radius [ expr 1.0 * [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "res" } {
+      incr argno
+      set res [ expr 1.0* [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }    
+    if { [ lindex $args $argno ] == "eps" } {
+      incr argno
+      set eps [ expr 1.0*[ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "type" } {
+      incr argno
+      set type [ expr [ lindex $args $argno ] ]
+      incr argno
+      continue
+    }
+    if { [ lindex $args $argno ] == "sigma" } {
+      incr argno
+      set sigma [ expr 1.0* [ lindex $args $argno ]] 
+      incr argno
+      continue
+    }
+    puts "did not understand arg [ lindex args $argno ]"
+    error "did not understand arg [ lindex args $argno ]"
+  }
+  set box_l_x [ lindex [ setmd box_l ] 0 ]
+
+  set pi 3.1415
+  set x [ expr $box_l_x/2 - $res/2]
+  set c1x [ expr $box_l_x/2 - $pore_width/2 - $upper_smoothing_radius ]
+  set c2x [ expr $box_l_x/2 - $pore_width/2 + $lower_smoothing_radius ]
+  
+  set z [ expr $pore_mouth - $pore_length ]
+  set c2z [ expr $pore_mouth - $pore_length  + $lower_smoothing_radius ]
+  set c1z [ expr $pore_mouth -  $upper_smoothing_radius ]
+  
+  
+  
+  while { $x > $c2x } {
+  
+  
+  doit $x $z 0 1
+  doit [ expr $box_l_x - $x ] $z  0 1
+    set x [ expr $x - $res ]
+  }
+  
+  set a [ expr ($c2x-$x)/$lower_smoothing_radius ]
+  set x [ expr $c2x - sin($a)*$lower_smoothing_radius ]
+  set z [ expr $c2z - cos($a)*$lower_smoothing_radius ]
+  
+  while { $a < $pi/2 } {
+  
+  
+  doit $x $z [ expr sin($a) ] [ expr cos($a) ]
+  doit [ expr $box_l_x - $x ] $z [ expr -sin($a) ] [ expr cos($a) ]
+    set a [ expr $a + $res/$lower_smoothing_radius ] 
+    set x [ expr $c2x - sin($a) *$lower_smoothing_radius]
+    set z [ expr $c2z - cos($a) *$lower_smoothing_radius]
+  
+  }
+  
+  set x [ expr $box_l_x/2 - $pore_width/2 ]
+  set z [ expr $c2z + $lower_smoothing_radius*sin($a - $pi/2) ]
+  
+  while { $z < $c1z } {
+  
+    doit $x $z 1 0
+    doit [ expr $box_l_x - $x ] $z -1 0
+    set z [ expr $z + $res ] 
+  }
+  set a [ expr ($z - $c1z)/$upper_smoothing_radius ]
+  set x [ expr $c1x + cos($a)*$upper_smoothing_radius ]
+  set z [ expr $c1z + sin($a)*$upper_smoothing_radius ]
+  
+  while { $a < $pi/2 } {
+  doit $x $z [ expr cos($a) ] [ expr sin($a) ]  
+  doit [ expr $box_l_x - $x ] $z [ expr -cos($a) ] [ expr sin($a) ]  
+  
+    set a [ expr $a + $res/$upper_smoothing_radius ] 
+    set x [ expr $c1x + cos($a)*$upper_smoothing_radius ]
+    set z [ expr $c1z + sin($a)*$upper_smoothing_radius ]
+  }
+  set z $pore_mouth
+  while { $x > 0 } {
+  doit $x $z 0 1
+  doit [ expr $box_l_x - $x ] $z 0 1
+  
+    set x [ expr $x - $res ]
+  }
+  
+  set x [ expr $box_l_x/2 - $res/2]
+  set z [ expr $pore_mouth + $channel_width ]
+  while { $x > 0 } { 
+    doit $x $z 0 -1
+    doit [expr $box_l_x - $x ] $z 0 -1
+  
+    set x [ expr $x - $res ]
+  }
 }
 
 
@@ -760,4 +961,8 @@ proc dielectric { args } {
   if { [ lindex $args 0 ] == "pore" } { 
     return [ eval dielectric_pore $args1 ]
   }
+  if { [ lindex $args 0 ] == "slitpore" } { 
+    return [ eval dielectric_slitpore $args1 ]
+  }
+  error "unable to understand argument given to dielectric"
 }
