@@ -1833,12 +1833,12 @@ void mpi_send_ext_torque(int pnode, int part, int flag, int mask, double torque[
     if (pnode == this_node) {
       Particle *p = local_particles[part];
       /* mask out old flags */
-      p->l.ext_flag &= ~mask;
+      p->p.ext_flag &= ~mask;
       /* set new values */
-      p->l.ext_flag |= flag;
+      p->p.ext_flag |= flag;
 
       if (mask & PARTICLE_EXT_TORQUE) 
-        memcpy(p->l.ext_torque, torque, 3*sizeof(double));
+        memcpy(p->p.ext_torque, torque, 3*sizeof(double));
     }
     else {
       s_buf[0] = flag; s_buf[1] = mask;
@@ -1861,12 +1861,12 @@ void mpi_send_ext_torque_slave(int pnode, int part)
       Particle *p = local_particles[part];
           MPI_Recv(s_buf, 2, MPI_INT, 0, SOME_TAG, comm_cart, MPI_STATUS_IGNORE);
       /* mask out old flags */
-      p->l.ext_flag &= ~s_buf[1];
+      p->p.ext_flag &= ~s_buf[1];
       /* set new values */
-      p->l.ext_flag |= s_buf[0];
+      p->p.ext_flag |= s_buf[0];
       
       if (s_buf[1] & PARTICLE_EXT_TORQUE)
-        MPI_Recv(p->l.ext_torque, 3, MPI_DOUBLE, 0, SOME_TAG, comm_cart, MPI_STATUS_IGNORE);
+        MPI_Recv(p->p.ext_torque, 3, MPI_DOUBLE, 0, SOME_TAG, comm_cart, MPI_STATUS_IGNORE);
     }
 
     on_particle_change();
@@ -1883,11 +1883,11 @@ void mpi_send_ext_force(int pnode, int part, int flag, int mask, double force[3]
   if (pnode == this_node) {
     Particle *p = local_particles[part];
     /* mask out old flags */
-    p->l.ext_flag &= ~mask;
+    p->p.ext_flag &= ~mask;
     /* set new values */
-    p->l.ext_flag |= flag;
+    p->p.ext_flag |= flag;
     if (mask & PARTICLE_EXT_FORCE)
-      memcpy(p->l.ext_force, force, 3*sizeof(double));
+      memcpy(p->p.ext_force, force, 3*sizeof(double));
   }
   else {
     s_buf[0] = flag; s_buf[1] = mask;
@@ -1908,12 +1908,12 @@ void mpi_send_ext_force_slave(int pnode, int part)
     Particle *p = local_particles[part];
         MPI_Recv(s_buf, 2, MPI_INT, 0, SOME_TAG, comm_cart, MPI_STATUS_IGNORE);
     /* mask out old flags */
-    p->l.ext_flag &= ~s_buf[1];
+    p->p.ext_flag &= ~s_buf[1];
     /* set new values */
-    p->l.ext_flag |= s_buf[0];
+    p->p.ext_flag |= s_buf[0];
     
     if (s_buf[1] & PARTICLE_EXT_FORCE)
-      MPI_Recv(p->l.ext_force, 3, MPI_DOUBLE, 0, SOME_TAG, comm_cart, MPI_STATUS_IGNORE);
+      MPI_Recv(p->p.ext_force, 3, MPI_DOUBLE, 0, SOME_TAG, comm_cart, MPI_STATUS_IGNORE);
   }
 
   on_particle_change();
