@@ -33,63 +33,104 @@
 /************************************************************/
 /*@{*/
 
-/** This bonded interaction was not set. */
+enum BondedInteraction{
+    /** This bonded interaction was not set. */
+    BONDED_IA_NONE = -1,
+    /** Type of bonded interaction is a FENE potential
+        (to be combined with Lennard Jones). */
+    BONDED_IA_FENE,
+    /** Type of bonded interaction is a HARMONIC potential. */
+    BONDED_IA_HARMONIC,
+    /** Type of bonded interaction is a bond angle potential. */
+    BONDED_IA_ANGLE_OLD,
+    /** Type of bonded interaction is a dihedral potential. */
+    BONDED_IA_DIHEDRAL,
+    /** Type of tabulated bonded interaction potential,
+        may be of bond length, of bond angle or of dihedral type. */
+    BONDED_IA_TABULATED,
+    /** Type of bonded interaction is a (-LJ) potential. */
+    BONDED_IA_SUBT_LJ,
+    /** Type of a Rigid/Constrained bond*/
+    BONDED_IA_RIGID_BOND,
+    /** Type of a virtual bond*/
+    BONDED_IA_VIRTUAL_BOND,
+    /** Type of bonded interaction is a bond angle -- constraint distance potential. */
+    BONDED_IA_ANGLEDIST,
+    /** Type of bonded interaction is a bond angle -- chain ends have angle with wall constraint */
+    BONDED_IA_ENDANGLEDIST,
+    /** Type of overlapped bonded interaction potential,
+        may be of bond length, of bond angle or of dihedral type. */
+    BONDED_IA_OVERLAPPED,
+    /** Type of bonded interaction is a bond angle cosine potential. */
+    BONDED_IA_ANGLE_HARMONIC,
+    /** Type of bonded interaction is a bond angle cosine potential. */
+    BONDED_IA_ANGLE_COSINE,
+    /** Type of bonded interaction is a bond angle cosine potential. */
+    BONDED_IA_ANGLE_COSSQUARE,
+    /** Type of bonded interaction is a hyperelastic stretching force. */
+    BONDED_IA_STRETCHING_FORCE,
+    /** Type of bonded interaction is a local area force. */
+    BONDED_IA_AREA_FORCE_LOCAL,
+    /** Type of bonded interaction is a bending force. */
+    BONDED_IA_BENDING_FORCE,
+    /** Type of bonded interaction is a bending force. */
+    BONDED_IA_VOLUME_FORCE,
+    /** Type of bonded interaction is a global area force. */
+    BONDED_IA_AREA_FORCE_GLOBAL,
+    /** Type of bonded interaction is a linear stretching force. */
+    BONDED_IA_STRETCHLIN_FORCE
+};
+/*
 #define BONDED_IA_NONE     -1
-/** Type of bonded interaction is a FENE potential 
-    (to be combined with Lennard Jones). */
 #define BONDED_IA_FENE      0
-/** Type of bonded interaction is a HARMONIC potential. */
 #define BONDED_IA_HARMONIC  1
-/** Type of bonded interaction is a bond angle potential. */
 #define BONDED_IA_ANGLE_OLD     2
-/** Type of bonded interaction is a dihedral potential. */
 #define BONDED_IA_DIHEDRAL  3
-/** Type of tabulated bonded interaction potential, 
-    may be of bond length, of bond angle or of dihedral type. */
 #define BONDED_IA_TABULATED 4
-/** Type of bonded interaction is a (-LJ) potential. */
 #define BONDED_IA_SUBT_LJ   5
-/** Type of a Rigid/Constrained bond*/
 #define BONDED_IA_RIGID_BOND  6
-/** Type of a virtual bond*/
 #define BONDED_IA_VIRTUAL_BOND  7
-/** Type of bonded interaction is a bond angle -- constraint distance potential. */
 #define BONDED_IA_ANGLEDIST     8
-/** Type of bonded interaction is a bond angle -- chain ends have angle with wall constraint */
 #define BONDED_IA_ENDANGLEDIST    9
-/** Type of overlapped bonded interaction potential, 
-    may be of bond length, of bond angle or of dihedral type. */
 #define BONDED_IA_OVERLAPPED 10
-/** Type of bonded interaction is a bond angle cosine potential. */ 
 #define BONDED_IA_ANGLE_HARMONIC 11
-/** Type of bonded interaction is a bond angle cosine potential. */ 
 #define BONDED_IA_ANGLE_COSINE 12
-/** Type of bonded interaction is a bond angle cosine potential. */ 
 #define BONDED_IA_ANGLE_COSSQUARE 13
-/** Type of bonded interaction is a hyperelastic stretching force. */
 #define BONDED_IA_STRETCHING_FORCE 14
-/** Type of bonded interaction is a local area force. */
-#define BONDED_IA_AREA_FORCE_LOCAL 15 
-/** Type of bonded interaction is a bending force. */
-#define BONDED_IA_BENDING_FORCE 16 
-/** Type of bonded interaction is a bending force. */
-#define BONDED_IA_VOLUME_FORCE 17 
-/** Type of bonded interaction is a global area force. */
-#define BONDED_IA_AREA_FORCE_GLOBAL 18 
-/** Type of bonded interaction is a linear stretching force. */
+#define BONDED_IA_AREA_FORCE_LOCAL 15
+#define BONDED_IA_BENDING_FORCE 16
+#define BONDED_IA_VOLUME_FORCE 17
+#define BONDED_IA_AREA_FORCE_GLOBAL 18
 #define BONDED_IA_STRETCHLIN_FORCE 19 
+*/
 
 /** Specify tabulated bonded interactions  */
+enum TabulatedBondedInteraction{
+    TAB_UNKNOWN = 0,
+    TAB_BOND_LENGTH,
+    TAB_BOND_ANGLE,
+    TAB_BOND_DIHEDRAL
+};
+/*
 #define TAB_UNKNOWN          0
 #define TAB_BOND_LENGTH      1
 #define TAB_BOND_ANGLE       2
 #define TAB_BOND_DIHEDRAL    3
+*/
 
 /** Specify overlapped bonded interactions  */
+enum OverlappedBondedInteraction{
+    OVERLAP_UNKNOWN = 0,
+    OVERLAP_BOND_LENGTH,
+    OVERLAP_BOND_ANGLE,
+    OVERLAP_BOND_DIHEDRAL
+};
+/*
 #define OVERLAP_UNKNOWN          0
 #define OVERLAP_BOND_LENGTH      1
 #define OVERLAP_BOND_ANGLE       2
 #define OVERLAP_BOND_DIHEDRAL    3
+*/
 
 /** cutoff for deactivated interactions. Below 0, so that even particles on
     top of each other don't interact by chance. */
@@ -130,20 +171,28 @@
    */
   /************************************************************/
   /*@{*/
-
+enum DipolarInteration{
   /** dipolar interation switched off (NONE). */
-   #define DIPOLAR_NONE       0
+    DIPOLAR_NONE = 0,
    /** dipolar method is P3M. */
-   #define DIPOLAR_P3M        1
+    DIPOLAR_P3M,
    /** Dipolar method is P3M plus DLC. */
-   #define DIPOLAR_MDLC_P3M    2
+    DIPOLAR_MDLC_P3M,
    /** Dipolar method is all with all and no replicas */
-   #define DIPOLAR_ALL_WITH_ALL_AND_NO_REPLICA  3
+    DIPOLAR_ALL_WITH_ALL_AND_NO_REPLICA,
    /** Dipolar method is magnetic dipolar direct sum */
-   #define DIPOLAR_DS  4
+    DIPOLAR_DS,
    /** Dipolar method is direct sum plus DLC. */
+    DIPOLAR_MDLC_DS
+};
+/*
+   #define DIPOLAR_NONE       0
+   #define DIPOLAR_P3M        1
+   #define DIPOLAR_MDLC_P3M    2
+   #define DIPOLAR_ALL_WITH_ALL_AND_NO_REPLICA  3
+   #define DIPOLAR_DS  4
    #define DIPOLAR_MDLC_DS  5
-
+*/
    /*@}*/
 #endif 
 
@@ -154,37 +203,54 @@
 */
 /************************************************************/
 /*@{*/
-
+enum ConstraintApplied{
 /** No constraint applied */
-#define CONSTRAINT_NONE 0
+    CONSTRAINT_NONE = 0,
 /** wall constraint applied */
-#define CONSTRAINT_WAL 1
+    CONSTRAINT_WAL,
 /** spherical constraint applied */
-#define CONSTRAINT_SPH 2
+    CONSTRAINT_SPH,
 /** (finite) cylinder shaped constraint applied */
-#define CONSTRAINT_CYL 3
+    CONSTRAINT_CYL,
 /** Rod-like charge. */
-#define CONSTRAINT_ROD 4
+    CONSTRAINT_ROD,
 /** Plate-like charge. */
-#define CONSTRAINT_PLATE 5
+    CONSTRAINT_PLATE,
 /** maze-like constraint applied */
-#define CONSTRAINT_MAZE 6
+    CONSTRAINT_MAZE,
 /** pore constraint applied */
-#define CONSTRAINT_PORE 7
+    CONSTRAINT_PORE,
 //ER
 /** External magnetic field constraint applied */
-#define CONSTRAINT_EXT_MAGN_FIELD 8
+    CONSTRAINT_EXT_MAGN_FIELD,
 //end ER
 /** Constraint for tunable-lsip boundary conditions */
-#define CONSTRAINT_PLANE 9
+    CONSTRAINT_PLANE,
 /** Constraint for tunable-lsip boundary conditions */
-#define CONSTRAINT_RHOMBOID 10
+    CONSTRAINT_RHOMBOID,
 /** Constraint for a stomatocyte boundary */
-#define CONSTRAINT_STOMATOCYTE 11
+    CONSTRAINT_STOMATOCYTE,
 /** slitpore constraint applied */
-#define CONSTRAINT_SLITPORE 12
+    CONSTRAINT_SLITPORE,
 /** Constraint for a hollow cone boundary */
+    CONSTRAINT_HOLLOW_CONE
+};
+/*
+#define CONSTRAINT_NONE 0
+#define CONSTRAINT_WAL 1
+#define CONSTRAINT_SPH 2
+#define CONSTRAINT_CYL 3
+#define CONSTRAINT_ROD 4
+#define CONSTRAINT_PLATE 5
+#define CONSTRAINT_MAZE 6
+#define CONSTRAINT_PORE 7
+#define CONSTRAINT_EXT_MAGN_FIELD 8
+#define CONSTRAINT_PLANE 9
+#define CONSTRAINT_RHOMBOID 10
+#define CONSTRAINT_STOMATOCYTE 11
+#define CONSTRAINT_SLITPORE 12
 #define CONSTRAINT_HOLLOW_CONE 13
+*/
 /*@}*/
 
 /* Data Types */
@@ -492,7 +558,7 @@ typedef struct {
  #ifdef DIPOLES
   double Dbjerrum;
   double Dprefactor;
-  int    Dmethod;
+  DipolarInteration    Dmethod;
  #endif
 
 } Coulomb_parameters;
@@ -620,7 +686,7 @@ typedef struct {
 /** Parameters for n-body tabulated potential (n=2,3,4). */
 typedef struct {
       char   *filename;
-      int    type;
+      TabulatedBondedInteraction    type;
       int    npoints;
       double minval;
       double maxval;
@@ -632,7 +698,7 @@ typedef struct {
 /** Parameters for n-body overlapped potential (n=2,3,4). */
 typedef struct {
       char   *filename;
-      int    type;
+      OverlappedBondedInteraction    type;
       double maxval;
       int    noverlaps;
       double *para_a;
@@ -714,7 +780,7 @@ typedef union {
 /** Defines parameters for a bonded interaction. */
 typedef struct {
   /** bonded interaction type. See \ref BONDED_IA_FENE "Type code for bonded" */
-  int type;
+  BondedInteraction type;
   /** (Number of particles - 1) interacting for that type */ 
   int num;
   /** union to store the different bonded interaction parameters. */
@@ -938,7 +1004,7 @@ typedef struct {
 /** Structure to specify a constraint. */
 typedef struct {
   /** type of the constraint. */
-  int type;
+  ConstraintApplied type;
 
   union {
     Constraint_wall wal;
@@ -1075,7 +1141,7 @@ inline int checkIfParticlesInteract(int i, int j) {
 }
 
 ///
-const char *get_name_of_bonded_ia(int i);
+const char *get_name_of_bonded_ia(BondedInteraction type);
 
 #ifdef BOND_VIRTUAL
 int virtual_set_params(int bond_type);
