@@ -1,4 +1,4 @@
-# Copyright (C) 2010,2011,2012,2013 The ESPResSo project
+# Copyright (C) 2010,2011,2012,2013,2014 The ESPResSo project
 # Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
 #    Max-Planck-Institute for Polymer Research, Theory Group
 #  
@@ -21,7 +21,6 @@
 source "tests_common.tcl"
 
 require_feature "LENNARD_JONES"
-require_feature "ADRESS" off
 
 puts "----------------------------------------------"
 puts "- Testcase analysis.tcl running on [format %02d [setmd n_nodes]] nodes: -"
@@ -232,10 +231,7 @@ test_catch {
     set F($i) [part $i pr f]
   }
 
-  
-  # to ensure force recalculation
-  invalidate_system
-  integrate 0
+  integrate 0 recalc_forces
 
   foreach obs $observables get_obs $get_observables {
     set rel_error [expr abs(([eval $get_obs] - $obs)/$obs)]
